package App::Git::Perl;

our $VERSION = '0.1.18';

use strict;
use warnings;

=head1 NAME

App::Git::Perl - adds custom git command "git perl" to make it easier to monitor latest changes in perl modules, and make you collaborate faster.

=head1 DESCRIPTION

This is a stub module, see L<git-perl> for details of the app.

=head1 AUTHOR

Nedzad Hrnjica

=head1 LICENSE

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

1;
